onStart method

Future<void> onStart(
  1. RpcContainer container
)

Called after the transport has started and all modules are configured.

Use this to open background connections, start timers, subscribe to message queues, etc.

Implementation

Future<void> onStart(RpcContainer container) async {}