onStart method
Called after the transport has started and all modules are configured.
Use this to open background connections, start timers, subscribe to message queues, etc.
Implementation
Future<void> onStart(RpcContainer container) async {}
Called after the transport has started and all modules are configured.
Use this to open background connections, start timers, subscribe to message queues, etc.
Future<void> onStart(RpcContainer container) async {}