RpcSpyEntry class

A single recorded RPC call entry produced by RpcCallSpy.

Constructors

RpcSpyEntry({required String serviceName, required String methodName, required String callType, required bool success, required Duration duration, required DateTime calledAt, required RpcContext context, Object? error})
const

Properties

calledAt DateTime
When this call was recorded.
final
callType String
One of 'unary', 'serverStream', 'clientStream', 'bidiStream'.
final
context → RpcContext
The RpcContext that was active during the call.
final
duration Duration
Wall-clock duration of the call (for streams: until the stream ended).
final
error Object?
The exception that was thrown, or null on success.
final
hashCode int
The hash code for this object.
no setterinherited
methodName String
Name of the RPC method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
Name of the RPC service.
final
success bool
True when the call completed without throwing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited